package com.ningdatech.pmapi.projectdeclared.manage;

import com.google.common.collect.Maps;
import com.ningdatech.pmapi.projectdeclared.model.dto.DefaultDeclaredDTO;
import com.ningdatech.pmapi.projectlib.enumeration.ProjectStatusEnum;
import lombok.RequiredArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.stereotype.Component;
import javax.annotation.PostConstruct;
import java.util.Map;
import java.util.function.Function;

/**
 * @Classname DefaultDeclaredProjectManage
 *
 * @Description
 * @Date 2023/2/14 17:12
 * @Author PoffyZhang
 */
@Component
@Slf4j
@RequiredArgsConstructor
public class DefaultDeclaredProjectManage {

    private final DeclaredProjectManage declaredProjectManage;

    private final ConstructionPlanManage constructionPlanManage;

    private final PrequalificationDeclaredProjectManage prequalificationDeclaredProjectManage;
    public Map<Integer, Function<DefaultDeclaredDTO,String>> startProcessMap = Maps.newHashMap();

    /**
     *  初始化业务分派逻辑,代替了if-else部分
     *  key: 枚举 状态值
     *  value: lambda表达式,最终会获取发起实例的函数
     */
    @PostConstruct
    public void startProcessInit(){
        startProcessMap.put(ProjectStatusEnum.UNDER_INTERNAL_AUDIT_NOT_PASS.getCode(),
                dto->declaredProjectManage.reStartTheProcess(dto));
        startProcessMap.put(ProjectStatusEnum.SCHEME_REVIEW_FAILED.getCode(),
                dto->constructionPlanManage.startTheProcess(dto));
        startProcessMap.put(ProjectStatusEnum.PREQUALIFICATION_FAILED.getCode(),
                dto->prequalificationDeclaredProjectManage.startTheProcess(dto));
        startProcessMap.put(ProjectStatusEnum.THE_JOINT_REVIEW_OF_PROVINCIAL_DEPARTMENTS_FAILED.getCode(),
                dto->null);
    }

}
